nbxmpp.proxy_connectors.SOCKS5Connector

Package nbxmpp :: Module proxy_connectors :: Class SOCKS5Connector |
[hide private]
[frames] | no frames]

# Class SOCKS5Connector

source code

SOCKS5 proxy connection class. Allows to use SOCKS5 proxies with (optionally) simple authentication (only USERNAME/PASSWORD auth)

Instance Methods | [hide private]
start_connecting(self) | source code
_on_greeting_sent(self, reply) | source code
_on_proxy_auth(self, reply) | source code
_on_req_sent(self, reply) | source code
Inherited from `ProxyConnector`: `__init__`, `connecting_over`

Class Methods | [hide private]
Inherited from `ProxyConnector`: `get_instance`

Method Details | [hide private]

### start_connecting(self) | source code
Overrides: ProxyConnector.start_connecting

### _on_greeting_sent(self, reply) | source code

### _on_proxy_auth(self, reply) | source code

### _on_req_sent(self, reply) | source code